==> haskell-wai-3.2.1.2-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai
version: 3.2.1.2
id: wai-3.2.1.2-9zkTqO0kNDM5rsC40iCXZx
key: wai-3.2.1.2-9zkTqO0kNDM5rsC40iCXZx
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: https://github.com/yesodweb/wai
synopsis: Web Application Interface.
description:
    Provides a common protocol for communication between web applications and web servers.
    .
    API docs and the README are available at <http://www.stackage.org/package/wai>.
category: Web
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Network.Wai Network.Wai.Internal
abi: b2aeea9f8db6a5e81f4a8b4e721315c7
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wai-3.2.1.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/wai-3.2.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/wai-3.2.1.2
hs-libraries: HSwai-3.2.1.2-9zkTqO0kNDM5rsC40iCXZx
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    network-2.6.3.4-9dk35Sk3nk1BI7Jw9SJICT
    http-types-0.9.1-L0SXZjYb79NLj6p0SwccQX
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz transformers-0.5.2.0
    vault-0.3.1.0-81QCypRRNkaHzxLwWgOdau
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             network-2.6.3.4-9dk35Sk3nk1BI7Jw9SJICT=3bb40bf00d3257de945a134963a298b0
             http-types-0.9.1-L0SXZjYb79NLj6p0SwccQX=39fa7a400c896fb5d30c824d62823b68
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             vault-0.3.1.0-81QCypRRNkaHzxLwWgOdau=908b99e386dd6dfcfae3b19596f778c3
haddock-interfaces: /usr/share/doc/haskell-wai/html/wai.haddock
haddock-html: /usr/share/doc/haskell-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-3.2.1.2-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai
version: 3.2.1.2
id: wai-3.2.1.2-Hdo9Dh1p8Ed7AH7djcZRAH
key: wai-3.2.1.2-Hdo9Dh1p8Ed7AH7djcZRAH
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: https://github.com/yesodweb/wai
synopsis: Web Application Interface.
description:
    Provides a common protocol for communication between web applications and web servers.
    .
    API docs and the README are available at <http://www.stackage.org/package/wai>.
category: Web
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Network.Wai Network.Wai.Internal
abi: 11bbac06985e46fc8f6f9fa02afc8842
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wai-3.2.1.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/wai-3.2.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/wai-3.2.1.2
hs-libraries: HSwai-3.2.1.2-Hdo9Dh1p8Ed7AH7djcZRAH
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    network-2.6.3.4-5QQX2Kbe495F2cbHmSR7FO
    http-types-0.9.1-I5VXdG5r7Fv5gm7UD4yo3B
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz transformers-0.5.2.0
    vault-0.3.1.0-81QCypRRNkaHzxLwWgOdau
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             network-2.6.3.4-5QQX2Kbe495F2cbHmSR7FO=1e0aca6235e9d0fee0939ce314445bf3
             http-types-0.9.1-I5VXdG5r7Fv5gm7UD4yo3B=1fabab8f133df5a739212b62b9cfb522
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             vault-0.3.1.0-81QCypRRNkaHzxLwWgOdau=908b99e386dd6dfcfae3b19596f778c3
haddock-interfaces: /usr/share/doc/haskell-wai/html/wai.haddock
haddock-html: /usr/share/doc/haskell-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
